\[build-system]

requires = \["setuptools>=68", "wheel"]

build-backend = "setuptools.build\_meta"



\[project]

name = "romplas-hello"

version = "0.0.1"

description = "Pacote de exemplo da ROMPLAS"

readme = "README.md"

requires-python = ">=3.9"

authors = \[{ name = "Alberto MKt", email = "marketing@romplas.com.br" }]

license = { text = "MIT" }



\[tool.setuptools.packages.find]

where = \["src"]

# romplas-hello

Pacote de exemplo para publicação no PyPI.

